from .exceptions import DhwaniAPIError
import requests
def vision_caption(client, file_path, length="short"):
    with open(file_path, "rb") as f:
        files = {"file": f}
        data = {"length": length}
        resp = requests.post(
            f"{client.api_base}/caption/",
            headers=client._headers(),
            files=files,
            data=data
        )
    if resp.status_code != 200:
        raise DhwaniAPIError(resp)
    return resp.json()

class Vision:
    @staticmethod
    def caption(*args, **kwargs):
        from . import _get_client
        return _get_client().caption(*args, **kwargs)



from .exceptions import DhwaniAPIError
import requests
def chat_create(client, prompt, **kwargs):
    resp = requests.post(
        f"{client.api_base}/chat",
        headers={**client._headers(), "Content-Type": "application/json"},
        json={"prompt": prompt, **kwargs}
    )
    if resp.status_code != 200:
        raise DhwaniAPIError(resp)
    return resp.json()

class Chat:
    @staticmethod
    def create(prompt, **kwargs):
        from . import _get_client
        return _get_client().chat(prompt, **kwargs)



import requests
from .exceptions import DhwaniAPIError

def document_ocr(client, file_path, language=None):
    """OCR a document (image/PDF) and return extracted text."""
    with open(file_path, "rb") as f:
        files = {"file": f}
        data = {}
        if language:
            data["language"] = language
        resp = requests.post(
            f"{client.api_base}/v1/document/ocr",
            headers=client._headers(),
            files=files,
            data=data
        )
    if resp.status_code != 200:
        raise DhwaniAPIError(resp)
    return resp.json()

def document_translate(client, file_path, src_lang, tgt_lang):
    """Translate a document (image/PDF with text) from src_lang to tgt_lang."""
    with open(file_path, "rb") as f:
        files = {"file": f}
        data = {
            "src_lang": src_lang,
            "tgt_lang": tgt_lang
        }
        resp = requests.post(
            f"{client.api_base}/v1/document/translate",
            headers=client._headers(),
            files=files,
            data=data
        )
    if resp.status_code != 200:
        raise DhwaniAPIError(resp)
    return resp.json()

def document_summarize(client, file_path, language=None):
    """Summarize a document (image/PDF/text)."""
    with open(file_path, "rb") as f:
        files = {"file": f}
        data = {}
        if language:
            data["language"] = language
        resp = requests.post(
            f"{client.api_base}/v1/document/summarize",
            headers=client._headers(),
            files=files,
            data=data
        )
    if resp.status_code != 200:
        raise DhwaniAPIError(resp)
    return resp.json()

class Documents:
    @staticmethod
    def ocr(file_path, language=None):
        from . import _get_client
        return _get_client().document_ocr(file_path, language)

    @staticmethod
    def translate(file_path, src_lang, tgt_lang):
        from . import _get_client
        return _get_client().document_translate(file_path, src_lang, tgt_lang)

    @staticmethod
    def summarize(file_path, language=None):
        from . import _get_client
        return _get_client().document_summarize(file_path, language)



from .client import DhwaniClient
from .chat import Chat
from .audio import Audio
from .vision import Vision
from .asr import ASR
from .exceptions import DhwaniAPIError

__all__ = ["DhwaniClient", "Chat", "Audio", "Vision", "ASR", "DhwaniAPIError"]

# Optionally, instantiate a default client for convenience
api_key = None
api_base = "http://localhost:7860"

def _get_client():
    global _client
    if "_client" not in globals() or _client is None:
        from .client import DhwaniClient
        globals()["_client"] = DhwaniClient(api_key=api_key, api_base=api_base)
    return globals()["_client"]

class chat:
    @staticmethod
    def create(prompt, **kwargs):
        return _get_client().chat(prompt, **kwargs)

class audio:
    @staticmethod
    def speech(*args, **kwargs):
        return _get_client().speech(*args, **kwargs)

class vision:
    @staticmethod
    def caption(*args, **kwargs):
        return _get_client().caption(*args, **kwargs)

class asr:
    @staticmethod
    def transcribe(*args, **kwargs):
        return _get_client().transcribe(*args, **kwargs)



import os
import requests
from .exceptions import DhwaniAPIError

class DhwaniClient:
    def __init__(self, api_key=None, api_base=None):
        self.api_key = api_key or os.getenv("DHWANI_API_KEY")
        self.api_base = "https://dwani-dwani-server-workshop.hf.space"
        #self.api_base = api_base or os.getenv("DHWANI_API_BASE", "http://localhost:7860")
        if not self.api_key:
            raise ValueError("DHWANI_API_KEY not set")

    def _headers(self):
        return {"X-API-Key": self.api_key}

    def chat(self, prompt, **kwargs):
        from .chat import chat_create
        return chat_create(self, prompt, **kwargs)

    def speech(self, *args, **kwargs):
        from .audio import audio_speech
        return audio_speech(self, *args, **kwargs)

    def caption(self, *args, **kwargs):
        from .vision import vision_caption
        return vision_caption(self, *args, **kwargs)

    def transcribe(self, *args, **kwargs):
        from .asr import asr_transcribe
        return asr_transcribe(self, *args, **kwargs)
    def document_ocr(self, file_path, language=None):
        from .docs import document_ocr
        return document_ocr(self, file_path, language)

    def document_translate(self, file_path, src_lang, tgt_lang):
        from .docs import document_translate
        return document_translate(self, file_path, src_lang, tgt_lang)

    def document_summarize(self, file_path, language=None):
        from .docs import document_summarize
        return document_summarize(self, file_path, language)

